# django-events

Django application allow to create site warnings, make subscription, and receive notifies.


## Install


```
pip install django-site-warnings
```


## Releases


### v0.1.4 2021/04/08

- Make title length longer.

### v0.1.2 2021/04/08

- First release.
